Appearances
Appearances()Returns the Appearances table as a DataFrame.
The Appearances table contains information about player appearances by position. The columns of the table are documented as the function returns.
Returns
yearID : int-
Year
teamID : str-
Team
lgID : str-
League
playerID : str-
Player ID code
G_all : int-
Total games played
GS : int-
Games started
G_batting : int-
Games in which player batted
G_defense : int-
Games in which player appeared on defense
G_p : int-
Games as pitcher
G_c : int-
Games as catcher
G_1b : int-
Games as first baseman
G_2b : int-
Games as second baseman
G_3b : int-
Games as third baseman
G_ss : int-
Games as shortstop
G_lf : int-
Games as left fielder
G_cf : int-
Games as center fielder
G_rf : int-
Games as right fielder
G_of : int-
Games as outfielder (if a player appeared in a single game at multiple OF positions, this will count as one g_OF game)
G_dh : int-
Games as designated hitter
G_ph : int-
Games as pinch hitter
G_pr : int-
Games as pinch runner