AwardsManagers
AwardsManagers()Returns the AwardsManagers table as a DataFrame.
The AwardsManagers table contains information about awards won by managers. The columns of the table are documented as the function returns.
Returns
playerID : str-
Manager ID code
awardID : str-
Name of award won
yearID : int-
Year
lgID : str-
League
tie : str-
Award was a tie (Y or N)
notes : str-
Notes about the award