AwardsPlayers
AwardsPlayers()Returns the AwardsPlayers table as a DataFrame.
The AwardsPlayers table contains information about awards won by players. The columns of the table are documented as the function returns.
Returns
playerID : str-
Player ID code
awardID : str-
Name of award won
yearID : int-
Year
lgID : str-
League
tie : str-
Award was a tie (Y or N)
notes : str-
Notes about the award