Batting
Batting()Returns the Batting table as a DataFrame.
The Batting table contains yearly batting statistics for all players. The columns of the table are documented as the function returns.
Returns
playerID : str-
Player ID code
yearID : int-
Year
stint : int-
Player’s stint (order of appearances within a season)
teamID : str-
Team
lgID : str-
League
G : int-
Games
AB : int-
At Bats
R : int-
Runs
H : int-
Hits
: 2B : int-
Doubles
: 3B : int-
Triples
HR : int-
Homeruns
RBI : int-
Runs Batted In
SB : int-
Stolen Bases
CS : int-
Caught Stealing
BB : int-
Base on Balls
SO : int-
Strikeouts
IBB : int-
Intentional walks
HBP : int-
Hit by pitch
SH : int-
Sacrifice hits
SF : int-
Sacrifice flies
GIDP : int-
Grounded into double plays