BattingPost
BattingPost()Returns the BattingPost table as a DataFrame.
The BattingPost table contains postseason batting statistics for all players. The columns of the table are documented as the function returns.
Returns
yearID : int-
Year
round : str-
Level of playoffs
playerID : str-
Player ID code
teamID : str-
Team
lgID : str-
League
G : int-
Games
AB : int-
At Bats
R : int-
Runs
H : int-
Hits
: 2B : int-
Doubles
: 3B : int-
Triples
HR : int-
Homeruns
RBI : int-
Runs Batted In
SB : int-
Stolen Bases
CS : int-
Caught stealing
BB : int-
Base on Balls
SO : int-
Strikeouts
IBB : int-
Intentional walks
HBP : int-
Hit by pitch
SH : int-
Sacrifices
SF : int-
Sacrifice flies
GIDP : int-
Grounded into double plays