Fielding
Fielding()Returns the Fielding table as a DataFrame.
The Fielding table contains yearly fielding statistics for all players. The columns of the table are documented as the function returns.
Returns
playerID : str-
Player ID code
yearID : int-
Year
stint : int-
Player’s stint (order of appearances within a season)
teamID : str-
Team
lgID : str-
League
POS : str-
Position
G : int-
Games
GS : int-
Games Started
InnOuts : int-
Time played in the field expressed as outs
PO : int-
Putouts
A : int-
Assists
E : int-
Errors
DP : int-
Double Plays
PB : int-
Passed Balls (by catchers)
WP : int-
Wild Pitches (by catchers)
SB : int-
Opponent Stolen Bases (by catchers)
CS : int-
Opponents Caught Stealing (by catchers)
ZR : float-
Zone Rating