FieldingPost
FieldingPost()Returns the FieldingPost table as a DataFrame.
The FieldingPost table contains postseason fielding statistics for all players. The columns of the table are documented as the function returns.
Returns
playerID : str-
Player ID code
yearID : int-
Year
teamID : str-
Team
lgID : str-
League
round : str-
Level of playoffs
POS : str-
Position Position
G : int-
Games
GS : int-
Games Started
InnOuts : int-
Time played in the field expressed as outs
PO : int-
Putouts
A : int-
Assists
E : int-
Errors
DP : int-
Double Plays
TP : int-
Triple Plays
PB : int-
Passed Balls
SB : int-
Stolen Bases allowed (by catcher)
CS : int-
Caught Stealing (by catcher)