HallOfFame
HallOfFame()Returns the HallOfFame table as a DataFrame.
The HallOfFame table contains information about Hall of Fame voting and inductions. The columns of the table are documented as the function returns.
Returns
playerID : str-
Player ID code
yearID : int-
Year of ballot
votedBy : str-
Method by which player was voted upon
ballots : int-
Total ballots cast in that year
needed : int-
Number of votes needed for selection in that year
votes : int-
Total votes received
inducted : str-
Whether player was inducted by that vote or not (Y or N)
category : str-
Category in which candidate was honored
needed_note : str-
Explanation of qualifiers for special elections, revised in 2023 to include important notes about the record