HomeGames
HomeGames()Returns the HomeGames table as a DataFrame.
The HomeGames table contains information about home games played by teams. The columns of the table are documented as the function returns.
Returns
yearkey : int-
Year
leaguekey : str-
League
teamkey : str-
Team ID
parkkey : str-
Ballpark ID
spanfirst : datetime-
First date of operation (yyyy-mm-dd)
spanlast : datetime-
Last date of operation (yyyy-mm-dd)
games : int-
Total number of games
openings : int-
Total number of paid dates played (games with attendance, note that doubleheaders may make the openings less than games)
attendance : int-
Total attendance