Managers
Managers()Returns the Managers table as a DataFrame.
The Managers table contains information about team managers. The columns of the table are documented as the function returns.
Returns
playerID : str-
Player ID Number
yearID : int-
Year
teamID : str-
Team
lgID : str-
League
inseason : int-
Managerial order, in order of appearance during the year. One if the individual managed the team the entire year
G : int-
Games managed
W : int-
Wins
L : int-
Losses
rank : int-
Team’s final position in standings that year
plyrMgr : str-
Player Manager (denoted by ‘Y’)