ManagersHalf
ManagersHalf()Returns the ManagersHalf table as a DataFrame.
The ManagersHalf table contains managerial information by half-season. The columns of the table are documented as the function returns.
Returns
playerID : str-
Manager ID code
yearID : int-
Year
teamID : str-
Team
lgID : str-
League
inseason : int-
Managerial order, in order of appearance during the year, 1 if the individual managed the team the entire year
half : int-
First or second half of season
G : int-
Games managed
W : int-
Wins
L : int-
Losses
rank : int-
Team’s position in standings for the half