People
People()Returns the People table as a DataFrame.
The People table contains biographical information for all players, managers, umpires, and executives in the database. The columns of the table are documented as the function returns.
Returns
playerID : str-
Player ID code
birthYear : int-
Year player was born
birthMonth : int-
Month player was born
birthDay : int-
Day player was born
birthCountry : str-
Country where player was born
birthState : str-
State where player was born
birthCity : str-
City where player was born
deathYear : int-
Year player died
deathMonth : int-
Month player died
deathDay : int-
Day player died
deathCountry : str-
Country where player died
deathState : str-
State where player died
deathCity : str-
City where player died
nameFirst : str-
Player’s first name
nameLast : str-
Player’s last name
nameGiven : str-
Player’s given name (typically first and middle)
weight : int-
Player’s weight in pounds
height : int-
Player’s height in inches
bats : str-
Player’s batting hand (left, right, or both)
throws : str-
Player’s throwing hand (left or right)
debut : datetime-
Date that player made first major league appearance
finalGame : datetime-
Date that player made last major league appearance
retroID : str-
ID used by Retrosheet
bbrefID : str-
ID used by Baseball Reference website