Pitching
Pitching()Returns the Pitching table as a DataFrame.
The Pitching table contains yearly pitching statistics for all players. The columns of the table are documented as the function returns.
Returns
playerID : str-
Player ID code
yearID : int-
Year
stint : int-
Player’s stint (order of appearances within a season)
teamID : str-
Team
lgID : str-
League
W : int-
Wins
L : int-
Losses
G : int-
Games
GS : int-
Games Started
CG : int-
Complete Games
SHO : int-
Shutouts
SV : int-
Saves
IPOuts : int-
Outs Pitched (innings pitched x 3)
H : int-
Hits
ER : int-
Earned Runs
HR : int-
Homeruns
BB : int-
Walks
SO : int-
Strikeouts
BAOpp : float-
Opponent’s Batting Average
ERA : float-
Earned Run Average
IBB : int-
Intentional Walks
WP : int-
Wild Pitches
HBP : int-
Batters Hit By Pitch
BK : int-
Balks
BFP : int-
Batters faced by Pitcher
GF : int-
Games Finished
R : int-
Runs Allowed
SH : int-
Sacrifices by opposing batters
SF : int-
Sacrifice flies by opposing batters
GIDP : int-
Grounded into double plays by opposing batter