PitchingPost
PitchingPost()Returns the PitchingPost table as a DataFrame.
The PitchingPost table contains postseason pitching statistics for all players. The columns of the table are documented as the function returns.
Returns
playerID : str-
Player ID code
yearID : int-
Year
round : str-
Level of playoffs
teamID : str-
Team
lgID : str-
League
W : int-
Wins
L : int-
Losses
G : int-
Games
GS : int-
Games Started
CG : int-
Complete Games
SHO : int-
Shutouts
SV : int-
Saves
IPOuts : int-
Outs Pitched (innings pitched x 3)
H : int-
Hits
ER : int-
Earned Runs
HR : int-
Homeruns
BB : int-
Walks
SO : int-
Strikeouts
BAOpp : float-
Opponents’ batting average
ERA : float-
Earned Run Average
IBB : int-
Intentional Walks
WP : int-
Wild Pitches
HBP : int-
Batters Hit By Pitch
BK : int-
Balks
BFP : int-
Batters faced by Pitcher
GF : int-
Games Finished
R : int-
Runs Allowed
SH : int-
Sacrifice Hits allowed
SF : int-
Sacrifice Flies allowed
GIDP : int-
Grounded into Double Plays