Schools
Schools()Returns the Schools table as a DataFrame.
The Schools table contains information about schools and colleges. The columns of the table are documented as the function returns.
Returns
schoolID : str-
School ID code
nameFull : str-
School name
city : str-
City where school is located
state : str-
State where school is located
country : str-
Country where school is located