Teams
Teams()Returns the Teams table as a DataFrame.
The Teams table contains yearly team statistics and standings information for all major league teams. The columns of the table are documented as the function returns.
Returns
yearID : int-
Year
lgID : str-
League
teamID : str-
Team
franchID : str-
Franchise (links to TeamsFranchise table)
divID : str-
Team’s division
Rank : int-
Position in final standings
G : int-
Games played
GHome : int-
Games played at home
W : int-
Wins
L : int-
Losses
DivWin : str-
Division Winner (Y or N)
WCWin : str-
Wild Card Winner (Y or N)
LgWin : str-
League Champion (Y or N)
WSWin : str-
World Series Winner (Y or N)
R : int-
Runs scored
AB : int-
At bats
H : int-
Hits by batters
: 2B : int-
Doubles
: 3B : int-
Triples
HR : int-
Homeruns by batters
BB : int-
Walks by batters
SO : int-
Strikeouts by batters
SB : int-
Stolen bases
CS : int-
Caught stealing
HBP : int-
Batters hit by pitch
SF : int-
Sacrifice flies
RA : int-
Opponents runs scored
ER : int-
Earned runs allowed
ERA : float-
Earned run average
CG : int-
Complete games
SHO : int-
Shutouts (team level)
SV : int-
Saves
IPOuts : int-
Outs Pitched (innings pitched x 3)
HA : int-
Hits allowed
HRA : int-
Homeruns allowed
BBA : int-
Walks allowed
SOA : int-
Strikeouts by pitchers
E : int-
Errors
DP : int-
Double Plays (team level)
FP : float-
Fielding percentage
name : str-
Team’s full name
park : str-
Name of team’s home ballpark
attendance : int-
Home attendance total
BPF : int-
Three-year park factor for batters
PPF : int-
Three-year park factor for pitchers
teamIDBR : str-
Team ID used by Baseball Reference website
teamIDlahman45 : str-
Team ID used in Lahman database version 4.5
teamIDretro : str-
Team ID used by Retrosheet